*search_web



This module will Help You to Search on Different Websites like Google,Youtube,etc.


You can search on more than 25 websites very easily by just 2 lines of code.


Websites Supported:-

	1.Google -google_search("Python")
	2.Youtube -youtube_search("Python")
	3.Bing -bing_search("Python")
	4.Quora -quora_search("5 Python Projects")
	5.Python -python_search("Input in Python")
	6.Twitter -twitter_search("Python")
	7.Facebook -facebook_search("Python")
	8.Pinterest -pinterest_search("Python images")
	9.Wikipedia -wikipedia_search("Python_(programming_language)")
	10.Amazon -amazon_search("Python Books")
	11.Reddit -reddit_search("Python")
	12.Imdb -imdb_search("python")
	13.TripAdvisor -tripadvisor_search("London")
	14.Walmart -walmart_search("python Books")
	15.Craigslist -craigslist_search("Python")
	16.Ebay -ebay_search("Python books")
	17.LinkedIn-Job Search, People Search, Learning
	18.Playstore -playstore_search("python")
	19.Headline -headline_search("python")
	20.Esty -esty_search("python")
	21.Indeed -indeed_search("Python Developer","USA")
	22.Apple -apple_search("Mac Book Pro")
	23.ESPN -espn_search("Cricket")
	24.Webmd -webmd_search("Python")
	25.New York Times -nytimes_search("Covid-19")
	26CNN -cnn_search("Us elections 2020")


    `Code` is to simple Just 2 lines of `Code`.

```python
from search_web import *
pysearch.google_search("How to Search via pysearch module Python")
```


FUNCTIONS
+amazon_search(text)
		Search on amazon (https://www.amazon.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+apple_search(text)
        Search on Apple (https://www.apple.com/us)


        Parameters
        -----------

        text:- The query which you want to search about (str)

    bing_search(text)
        Search on Bing (www.bing.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+cnn_search(text)
        Search on CNN (https://edition.cnn.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+craigslist_search(text)
        Search on craigslist (https://kolkata.craigslist.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+ebay_search(text)
        Search on Ebay (https://www.ebay.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

    espn_search(text)
        Search on Espn (https://www.espn.in)

        Parameters
        -----------

        text:- The query which you want to search about (str)

    esty_search(text)
        Search on Esty (https://www.etsy.c:om/in-en)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+facebook_search(text)
        Search on Facebook (https://facebook.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

    google_search(text)
        Search on Google (https://www.google.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

    headline_search(t
ext)
        Search on Headline (https://www.healthline.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+imdb_search(text)
        Search on imdb (https://www.imdb.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

    indeed_search(job_tit
le, location)
        Search on Indeed (https://in.indeed.com/m/jobs)

        Parameters
        -----------

        job_title:- Name of the Job (str)

        location:- Location (str)

+linkedin_job_sea
arch(text)
        Search on Linkedin (https://www.linkedin.com/jobs)

        Parameters
        -----------

        text:- The query which you want to search about (str)

    linkedin_learnin
ng_search(text)
        Search on Linkedin (https://www.linkedin.com/learning)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+linkedin_people_
_search(first_name, last_name)
        Search on Linkedin (https://www.linkedin.com/people-guest/pub)

        Parameters
        -----------

        first_name:- First Name of the person (str)

        last_name:- Last Name of the person (str)

+nytimes_search(text
)
        Search on New York Times (https://www.nytimes.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

    open(link)
        Opening Webpage Through webbrowser module

+pinterest_search
h(text)
        Search on Pinterest (https://in.pinterest.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+play_store_searc
ch(text)
        Search on Play Store (https://play.google.com/store)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+python_search(text)
        Search on Python.org (www.python.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+quora_search(text)
        Search on Quora (www.quora.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+reddit_search(text)
        Search on Reddit (https://www.reddit.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+tripadvisor_search(text)
        Search on Tripadvisor (https://www.tripadvisor.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+twitter_search(text
)
        Search on twitter (https://twitter.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+walmart_search(text
)
        Search on Walmart (https://www.walmart.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+webmd_search(text)
        Search on Webmd (https://www.webmd.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+wikipedia_search
h(text)
        Search on Wikipedia (https://en.m.wikipedia.org)

        Parameters
        -----------

        text:- The query which you want to search about (str)

+youtube_search(text
)
        Search on Youtube (https://www.youtube.com)

        Parameters
        -----------

        text:- The query which you want to search about (str)
        
        
        
        
Version-(0.0.1)-First Release


License-MIT
